####################################
The Python Pacs (Pypx) module - v0.1
####################################
***************
1. Overview
***************

Pypx is a simple Python wrapper around DCMTK and PyDicom. It provides 4 simple way to interact with the PACS:

1. **echo:** Ping the PACS to make sure it is online. Wrapper around DCMTK *echoscu*.

2. **find:** Find data on the PACS. Wrapper around DCMTK *findscu*.

3. **move:** Move data on the PACS. Wrapper around DCMTK *movescu*.

4. **listen:** Listen for incoming data from the PACS. Wrapper around DCMTK *storescp*.

***************
2. Installation
***************
***************
3. Usage
***************
Scripts
===============
Modules
===============